@@ -24,10 +24,10 @@ main (gint argc, char *argv[])
 	int token, init_results;
 	poptContext ctx;
 	char **args;
-
+	
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
-	
+
 	init_results = gnome_capplet_init("background-properties", VERSION,
 					  argc, argv, options, 0, &ctx);
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-ccbackground.png");
@@ -43,8 +43,6 @@ main (gint argc, char *argv[])
 					 background_image);
 		gnome_config_sync ();
 
-		/* this goes somewhere else eventually */
-		background_imlib_init ();
 		background_properties_init();
 	}
 
@@ -74,9 +72,6 @@ main (gint argc, char *argv[])
 	else
 		token = 1;
 
-	/* this goes somewhere else eventually */
-	background_imlib_init ();
-
         if(token) 
                 background_properties_init();
 
