@@ -45,6 +45,7 @@ static void
 keyboard_read(void)
 {
 	gboolean repeat_default, click_default;
+        gint event_base_return, error_base_return;
 
 	keyboard_rate = gnome_config_get_int("/Desktop/Keyboard/rate=-");
 	keyboard_delay = gnome_config_get_int("/Desktop/Keyboard/delay=-1");
@@ -59,9 +60,14 @@ keyboard_read(void)
 
 	if (keyboard_rate == -1 || keyboard_delay == -1) {
 #ifdef HAVE_X11_EXTENSIONS_XF86MISC_H
-		XF86MiscGetKbdSettings(GDK_DISPLAY(), &kbdsettings);
-		keyboard_rate = kbdsettings.rate;
-		keyboard_delay = kbdsettings.delay;
+		if (XF86MiscQueryExtension(GDK_DISPLAY(), &event_base_return, &error_base_return) == True) {
+                        XF86MiscGetKbdSettings(GDK_DISPLAY(), &kbdsettings);
+                        keyboard_rate = kbdsettings.rate;
+                        keyboard_delay = kbdsettings.delay;
+                } else {
+                        keyboard_rate = 5;
+                        keyboard_delay = 500;
+                }
 #else
 		/* FIXME: how to get the keyboard speed on non-xf86? */
 		keyboard_rate = 5;
@@ -98,12 +104,18 @@ keyboard_help(void)
 static void
 keyboard_apply(void)
 {
+        int event_base_return, error_base_return;
+
 	if (keyboard_repeat) {
 		XAutoRepeatOn(GDK_DISPLAY());
 #ifdef HAVE_X11_EXTENSIONS_XF86MISC_H
-		kbdsettings.rate =  keyboard_rate;
-		kbdsettings.delay = keyboard_delay;
-		XF86MiscSetKbdSettings(GDK_DISPLAY(), &kbdsettings);
+		if (XF86MiscQueryExtension(GDK_DISPLAY(), &event_base_return, &error_base_return) == True) {
+                        kbdsettings.rate =  keyboard_rate;
+                        kbdsettings.delay = keyboard_delay;
+                        XF86MiscSetKbdSettings(GDK_DISPLAY(), &kbdsettings);
+                } else {
+                        XAutoRepeatOff(GDK_DISPLAY());
+                }
 #endif
 	} else {
 		XAutoRepeatOff(GDK_DISPLAY());
