@@ -5,7 +5,8 @@
  */
 #include <config.h>
 #include "capplet-widget.h"
-#include "gnome.h"
+#include <gnome.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include "callbacks.h"
 #include "parser.h"
 #include <unistd.h>
@@ -200,6 +201,7 @@ main (int argc, char **argv)
 
 	init_results = gnome_capplet_init("screensaver-properties", VERSION,
 					  argc, argv, NULL, 0, NULL);
+        gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-ccscreensaver.png");
 	if (init_results < 0) {
                 g_warning ("an initialization error occurred while "
 			   "starting 'screensaver-properties-capplet'.\n"
