@@ -505,7 +505,7 @@ help (GtkWidget *capplet)
     break;
   }
 
-  tmp = gnome_help_file_find_file ("users-guide", helpfile);
+  tmp = gnome_help_file_find_file ("control-center", helpfile);
   if (tmp) {
     gnome_help_goto(0, tmp);
     g_free(tmp);
