@@ -65,7 +65,7 @@ void
 help_callback (GtkWidget *widget, gpointer data)
 {
         gchar *tmp;
-        tmp = gnome_help_file_find_file ("users-guide", "gcc.html");
+        tmp = gnome_help_file_find_file ("control-center", "index.html");
         if (tmp) {
                 gnome_help_goto(0, tmp);
                 g_free(tmp);
