@@ -5,13 +5,15 @@
 #include <config.h>
 #include <gnome.h>
 #include <gdk/gdkkeysyms.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include <stdio.h>
 #include "callbacks.h"
 #include "tree.h"
 #include "corba-glue.h"
 #include "capplet-manager.h"
 #include "gtk-multiview.h"
-
+#include "gdk_imlib.h"
+#include "splash.h"
 GtkWidget *main_window;
 GtkWidget *exit_dialog;
 GtkWidget *hpane;
@@ -49,6 +51,7 @@ static GnomeUIInfo parentMenu[] = {
         {GNOME_APP_UI_ENDOFINFO}
 };
 
+
 GtkWidget *
 create_exit_dialog (GList *apps)
 {
@@ -221,9 +224,8 @@ create_window ()
         multiview = gtk_multiview_new ();
         gtk_container_add (GTK_CONTAINER (container), multiview);
 
-        splash_screen = gtk_drawing_area_new ();
+        splash_screen = create_splash_screen ();
         /*gdk_imlib_load_file_to_pixmap ("splash.png", &temp_splash, NULL);*/
-        gtk_widget_set_usize (splash_screen, 300, 275);
 
         /* we put it all together... */
         gtk_container_add (GTK_CONTAINER (sw), tree);
@@ -276,6 +278,7 @@ main (int argc, char *argv[])
 	textdomain(PACKAGE);
 
         control_center_corba_gtk_init(&argc,argv);
+        gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/control-center.png");
         main_window = create_window ();
         control_center_corba_gtk_main (&argc, argv);
         return 0;
