@@ -256,8 +256,8 @@ create_splash_screen (void)
 	max_width = 0;
 	max_height = 0;
 	for (i = 0; i < end_system_info; i++) {
-		max_width = MAX (max_width, gdk_string_width (font, descriptions[i]));
-		max_height = MAX (max_height, gdk_string_height (font, descriptions[i]));
+		max_width = MAX (max_width, gdk_string_width (font, _(descriptions[i])));
+		max_height = MAX (max_height, gdk_string_height (font, _(descriptions[i])));
 	}
 	gdk_font_unref (font);
 	for (i = 0; i < end_system_info; i++) {
